@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "18.0.1+10" },
-            { "jdk", "18.0.1" },
-            { "release", "18.0.1" },
+            { "full", "21.0.2+13-LTS" },
+            { "jdk", "21.0.2" },
+            { "release", "21.0.2" },
         };
     }
 }
